"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Extract = void 0;
const tslib_1 = require("tslib");
const Path = tslib_1.__importStar(require("path"));
const stream_1 = require("stream");
const duplexer2_1 = tslib_1.__importDefault(require("duplexer2"));
const fstream_1 = require("fstream");
const unzipper_1 = require("unzipper");
function Extract({ path, strip = 0 }, onEntry) {
    const parser = (0, unzipper_1.Parse)();
    const outStream = new stream_1.Writable({ objectMode: true });
    outStream._write = function (entry, _encoding, callback) {
        if (entry.type === 'Directory') {
            callback();
            return;
        }
        const strippedPath = entry.path.split('/').slice(strip).join('/');
        onEntry(strippedPath);
        const extractPath = Path.join(path, strippedPath);
        const writer = (0, fstream_1.Writer)({ path: extractPath });
        entry.pipe(writer).on('error', callback).on('close', callback);
    };
    const extract = (0, duplexer2_1.default)(parser, outStream);
    parser.once('crx-header', function (crxHeader) {
        extract.crxHeader = crxHeader;
    });
    parser.pipe(outStream).on('finish', function () {
        extract.emit('close');
    });
    extract.promise = function () {
        return new Promise(function (resolve, reject) {
            extract.on('close', resolve);
            extract.on('error', reject);
        });
    };
    return extract;
}
exports.Extract = Extract;
//# sourceMappingURL=@utils.js.map